@@ -1,4 +1,8 @@
-from HTMLParser import HTMLParser
+'''
+These scraping implementations are used only for detecting PDF direct download links as necessary
+'''
+
+from html.parser import HTMLParser
 
 class RSC(HTMLParser):
   '''
@@ -10,7 +14,7 @@ class RSC(HTMLParser):
   #RSC scraping implementation
   def handle_starttag(self, tag, attrs):
     '''
-    PDF link handler; never gets explicity called by user
+    PDF link handler; never gets explicitly called by user
     '''
     for attr in attrs:
       if attr[0] == 'content':
@@ -26,7 +30,7 @@ class ECS(HTMLParser):
   #ECS scraping implementation
   def handle_starttag(self, tag, attrs):
     '''
-    PDF link handler; never gets explicity called by user
+    PDF link handler; never gets explicitly called by user
     '''
     if tag == 'a' and ('rel', 'view-full-text.pdf') in attrs:
       for attr in attrs:
@@ -43,7 +47,7 @@ class Nature(HTMLParser):
   #Nature scraping implementation
   def handle_starttag(self, tag, attrs):
     '''
-    PDF link handler; never gets explicity called by user
+    PDF link handler; never gets explicitly called by user
     '''
     if tag == 'a' and ( ('class', 'download-pdf') in attrs or ('id', 'download-pdf') in attrs ):
         for attr in attrs:
